# Change Log

## [0.5.0](https://github.com/dldevinc/ajax-views/tree/v0.5.0) - 2022-05-28
### ⚠ BREAKING CHANGES
- Dropped support for Python 3.5.

## [0.4.1](https://github.com/dldevinc/ajax-views/tree/v0.4.1) - 2021-02-08
- Add typing
- Improve tests
- Add Python 3.9 support
- Add Django 3.1 support

## [0.4.0](https://github.com/dldevinc/ajax-views/tree/v0.4.0) - 2020-07-14
- Drop Python 3.4 support
- Drop Django 1.8-1.10 support
